function [ngbrs]=findngbrs(system,whichAtoms)
% FINDNGBRS Creates a list of an atoms neighbor atoms and their attributes.
%   [NGBRS]=FINDNGBRS(SYSTEM,WHICHATOMS) is a 1 x LENGTH(WHICHATOMS) 
%   structure that, for each atom of whichAtoms, contains POS(position of
%   atom), name (name of atom), kind(kind of atom), numngbrs (atom's number
%   of neighbor atoms), disp ( numngbrs x 1 array of displacement between 
%   atom and all of its neighbor atoms), ngbrpos ( numngbrs x 3 array
%   containing positons of all atom's neighbor atoms), ngbrname( numngbrs x
%   1 array containing names of all of atom's neighbor atoms), ngbrkind (
%   numngbrs x 1 array containing kinds of all of atom's neighbor atoms),
%   cell (contains which cell each of atom's neighbors are in NOTE: [0 0 0]
%   is the home cell).
%
%   %Example:
%   >>sys=makesys;
%   >>atoms=[1 3 5];
%   >>ngbrsFor135=findngbrs(sys,atoms)
% 
%     ngbrsFor135 = 
% 
%     1x3 struct array with fields:
%         pos
%         name
%         kind
%         disp
%         numngbrs
%         ngbrpos
%         ngbrname
%         ngbrkind
%         cell
%         id
%   To access neighbor info for atom 3:
%   >>ngbrsFor135(2);
%
% See also PRINTNGBRS, WHICHCELL, MAKEIMAGESYS

%initialize
sys=system;

%create super cell of atoms and all needed imaginary atoms based on rcut
[supercell imgid]=makeImageSys(sys);

%how many atoms are neghbors being found for
le=length(whichAtoms);

%loop over whichAtoms, finding neighbors for each
for i=1:le
   iatom=whichAtoms(i);
   %find distance between whichAtom(i) and every other atom
   d=((supercell.pos(:,1)-sys.pos(iatom,1)).^2+(supercell.pos(:,2)-sys.pos(iatom,2)).^2+ (supercell.pos(:,3)-sys.pos(iatom,3)).^2).^0.5;
   masks=d<sys.rcut;
   maskList=[1:supercell.numatms]';
   mask=masks.*maskList;
   mask(iatom)=0;
   mask=mask(mask>0);
   %mask now contains which atoms are less than rcut 
   
   %whichAtoms properties...
   ngbrs(i).pos=sys.pos(iatom,:);
   ngbrs(i).name=sys.name(iatom);
   ngbrs(i).kind=sys.kind(iatom);
       
   %properties of whichAtoms' neighbors
   ngbrs(i).disp=d(mask);
   ngbrs(i).numngbrs=length(mask);
   ngbrs(i).ngbrpos=supercell.pos(mask,:);
   ngbrs(i).ngbrname=supercell.name(mask,:);
   ngbrs(i).ngbrkind=supercell.kind(mask);
   ngbrs(i).cell=whichCell(supercell,mask);
   ngbrs(i).id=imgid(mask);
end



