function [imgsys imgid]=makeImageSys(system)
% makeImageSys creates a system that contains all possible atoms within
%   SYSTEM.RCUT of the original SYSTEM [IMGSYS IDLIST]=makeImageSys(SYSYEM)
%   is a system structure that contains all the atoms that were contained
%   in SYSTEM as wel as all image atoms that could be within SYSTEM.RCUT
%   based on a tiling using the lattice vectors, SYSTEM.LATVEC.  If SYSTEM
%   does not have periodic boundary condtions along a vector direction
%   (based on SYSTEM.PBC), then MAKEIMAGESYS will not tile in that lattice
%   vector direction.  IMGID is a vector, for each image atom, of the
%   indices of the approppriate pre-image atom in the original system from
%   which it was mapped.
%
%   %Example:
%     >> sys=makesys
%
%     sys =
%
%            init: 'loadDefault'
%         fileout: 'MySystem' numatms: 100
%             dim: 3
%            beta: 0
%           press: 0
%             lat: 'random'
%          latvec: [3x3 double]
%             pos: [100x3 double]
%            kind: [100x1 double] name: [100x1 double]
%          potent: 'Ising'
%             eps: [2x2 double]
%            rcut: 1.4
%             pbc: [1 1 1]
%
%     >> imgsys=makeImageSys(sys)
%
%     imgsys =
%
%            init: 'loadDefault'
%         fileout: 'MySystem' numatms: 2700
%             dim: 3
%            beta: 0
%           press: 0
%             lat: 'random'
%          latvec: [3x3 double]
%             pos: [2700x3 double]
%            kind: [2700x1 double] name: [2700x1 double]
%          potent: 'Ising'
%             eps: [2x2 double]
%            rcut: 1.4
%             pbc: [1 1 1]
%
% See also FINDNGBRS, WHICHCELL

%initalize
sys=system;
sys.latvec=sys.latvec';

%create a mask of which atoms are real and which are imaginary
mag1=magnitude(sys.latvec(:,1));
mag2=magnitude(sys.latvec(:,2));
mag3=magnitude(sys.latvec(:,3));
sysid=[1:sys.numatms]';
tiles=ceil([sys.rcut/mag1 sys.rcut/mag2 sys.rcut/mag3]);

%tile in +/-latvec1 if sys.pbc allows
if(sys.pbc(1)==1)
    imagpos=[];
    imagname=[];
    imagkind=[];
    imagid=[];
    for i=1:tiles(1)
        imagpos=cat(1,imagpos,[sys.pos(:,1)+i*sys.latvec(1,1) sys.pos(:,2)+i*sys.latvec(2,1) sys.pos(:,3)+i*sys.latvec(3,1)]);
        imagpos=cat(1,imagpos,[sys.pos(:,1)-i*sys.latvec(1,1) sys.pos(:,2)-i*sys.latvec(2,1) sys.pos(:,3)-i*sys.latvec(3,1)]);
        imagname=cat(1,imagname,sys.name);
        imagname=cat(1,imagname,sys.name);
        imagkind=cat(1,imagkind,sys.kind);
        imagkind=cat(1,imagkind,sys.kind);
        imagid=cat(1,imagid,sysid);
        imagid=cat(1,imagid,sysid);
    end

    sys.pos=cat(1,sys.pos,imagpos);
    sys.name=cat(1,sys.name,imagname);
    sys.kind=cat(1,sys.kind,imagkind);
    sysid=cat(1,sysid,imagid);
end

%tile in +/-latvec2 if sys.pbc allows
if(sys.pbc(2)==1)
    imagpos=[];
    imagname=[];
    imagkind=[];
    for i=1:tiles(2)
        imagpos=cat(1,imagpos,[sys.pos(:,1)+i*sys.latvec(1,2) sys.pos(:,2)+i*sys.latvec(2,2) sys.pos(:,3)+i*sys.latvec(3,2)]);
        imagpos=cat(1,imagpos,[sys.pos(:,1)-i*sys.latvec(1,2) sys.pos(:,2)-i*sys.latvec(2,2) sys.pos(:,3)-i*sys.latvec(3,2)]);
        imagname=cat(1,imagname,sys.name);
        imagname=cat(1,imagname,sys.name);
        imagkind=cat(1,imagkind,sys.kind);
        imagkind=cat(1,imagkind,sys.kind);
        imagid=cat(1,imagid,sysid);
        imagid=cat(1,imagid,sysid);
    end

    sys.pos=cat(1,sys.pos,imagpos);
    sys.name=cat(1,sys.name,imagname);
    sys.kind=cat(1,sys.kind,imagkind);
    sysid=cat(1,sysid,imagid);
    si=size(imagpos);
end

%tile in +/-latvec3 if sys.pbc allows
if(sys.pbc(3)==1)
    imagpos=[];
    imagname=[];
    imagkind=[];
    for i=1:tiles(3)
        imagpos=cat(1,imagpos,[sys.pos(:,1)+i*sys.latvec(1,3) sys.pos(:,2)+i*sys.latvec(2,3) sys.pos(:,3)+i*sys.latvec(3,3)]);
        imagpos=cat(1,imagpos,[sys.pos(:,1)-i*sys.latvec(1,3) sys.pos(:,2)-i*sys.latvec(2,3) sys.pos(:,3)-i*sys.latvec(3,3)]);
        imagname=cat(1,imagname,sys.name);
        imagname=cat(1,imagname,sys.name);
        imagkind=cat(1,imagkind,sys.kind);
        imagkind=cat(1,imagkind,sys.kind);
        imagid=cat(1,imagid,sysid);
        imagid=cat(1,imagid,sysid);
    end

    sys.pos=cat(1,sys.pos,imagpos);
    sys.name=cat(1,sys.name,imagname);
    sys.kind=cat(1,sys.kind,imagkind);
    sysid=cat(1,sysid,imagid);
    si=size(imagpos);
end

si=size(sys.pos);
sys.numatms=si(1);
imgsys=sys;
imgid=sysid;
imgsys.latvec=sys.latvec';