function [supercell]=makesupercell(system, vectors)
% MAKESUPERCELL creates a supercell system of a system.
%   [SUPERCELL]=MAKESUPERCELL(SYSTEM, VECTORS) is a system structure that,
%   based on SYSTEM.POS (atom positions) and SYSTEM.LATVEC (lattice
%   vectors), finds those atoms that fit within the parallelapiped that is
%   defined by VECTORS.  
%
%   %Example:
%     >> sys=makesys
% 
%     sys = 
% 
%            init: 'loadDefault'
%         fileout: 'MySystem'
%         numatms: 100
%             dim: 3
%            beta: 0
%           press: 0
%             lat: 'random'
%          latvec: [3x3 double]
%             pos: [100x3 double]
%            kind: [100x1 double]
%            name: [100x1 double]
%          potent: 'Ising'
%             eps: [2x2 double]
%            rcut: 1
%             pbc: [1 1 1]
% 
%     >> vec=2*sys.latvec
% 
%     vec =
% 
%         10     2     0
%          2    12     0
%          2     2     8
% 
%     >> supercell=makesupercell(sys,vec)
% 
%     supercell = 
% 
%            init: 'loadDefault'
%         fileout: 'MySystem'
%         numatms: 748
%             dim: 3
%            beta: 0
%           press: 0
%             lat: 'random'
%          latvec: [3x3 double]
%             pos: [748x3 double]
%            kind: [748x1 double]
%            name: [748x1 double]
%          potent: 'Ising'
%             eps: [2x2 double]
%            rcut: 1
%             pbc: [1 1 1]
%
%     >> supercell.latvec
% 
%     ans =
% 
%         10     2     0
%          2    12     0
%          2     2     8
%
%   The above example creates a super cell where the p.piped that the super
%   cell is to fit in is defined as twice the original lattice vectors.
%   Note that supercell.latvec are the supercell lattice vectors, not the
%   original lattice vectors.
%
% See also MAKEIMAGESYS

%initialize
sys=system;
latvec=sys.latvec';
eps=1.0e-12;
vectors=vectors';
[m,n]=size(sys.kind);
if (n>m)
    sys.kind=sys.kind';
end


%parralelapiped that the newsystem is to fit into
ppiped=vectors;

%8 points of the ppiped
pts=[0 0 0; ppiped(:,1)'; ppiped(:,2)'; ppiped(:,3)'; ppiped(:,1)'+ppiped(:,2)'; ppiped(:,1)'+ppiped(:,3)'; ppiped(:,2)'+ppiped(:,3)'; ppiped(:,1)'+ppiped(:,2)'+ppiped(:,3)'];

%determine how many tilings of each lattice vector are needed  to cover all
%space inside ppiped

coeff=(latvec\pts')';
 
tilespos=floor([max(coeff(:,1)) max(coeff(:,2)) max(coeff(:,3))]);
 
tilesneg=floor([min(coeff(:,1)) min(coeff(:,2)) min(coeff(:,3))]);
 
%tile positions out tilespos and tilesneg times
newpos=sys.pos;
newkind=sys.kind;
newname=sys.name;

%1st, pos latvec1 
 for i=1:tilespos(1)
    newpos=cat(1, newpos, [sys.pos(:,1)+i*latvec(1,1) sys.pos(:,2)+i*latvec(2,1) sys.pos(:,3)+i*latvec(3,1)]);
    newkind=cat(1,newkind,sys.kind);
        newname=cat(1,newname,sys.name);
 end
 
 %do this in negative latvec1 tilesneg(1) times
  for i=tilesneg(1):-1
    newpos=cat(1, newpos, [sys.pos(:,1)+i*latvec(1,1) sys.pos(:,2)+i*latvec(2,1) sys.pos(:,3)+i*latvec(3,1)]);
    newkind=cat(1,newkind,sys.kind);
            newname=cat(1,newname,sys.name);
  end
 
%make sys.pos = new pos to begin tiling in + latvec2 direction
sys.pos=newpos;
sys.kind=newkind;
sys.name=newname;

%repeat in latvec2
 for i=1:tilespos(2)
    newpos=cat(1, newpos, [sys.pos(:,1)+i*latvec(1,2) sys.pos(:,2)+i*latvec(2,2) sys.pos(:,3)+i*latvec(3,2)]);
    newkind=cat(1,newkind,sys.kind);
                newname=cat(1,newname,sys.name);
 end
 
 for i=tilesneg(2):-1
    newpos=cat(1, newpos, [sys.pos(:,1)+i*latvec(1,2) sys.pos(:,2)+i*latvec(2,2) sys.pos(:,3)+i*latvec(3,2)]);
    newkind=cat(1,newkind,sys.kind);
                newname=cat(1,newname,sys.name);
 end
  
%make sys.pos = new pos to begin tiling in + latvec3 direction
sys.pos=newpos;
sys.kind=newkind;
sys.name=newname;

 %repeat in latvec3
 for i=1:tilespos(3)
    newpos=cat(1, newpos, [sys.pos(:,1)+i*latvec(1,3) sys.pos(:,2)+i*latvec(2,3) sys.pos(:,3)+i*latvec(3,3)]);
    newkind=cat(1,newkind,sys.kind);
                    newname=cat(1,newname,sys.name);
 end
 
 for i=tilesneg(3):-1
    newpos=cat(1, newpos, [sys.pos(:,1)+i*latvec(1,3) sys.pos(:,2)+i*latvec(2,3) sys.pos(:,3)+i*latvec(3,3)]);
    newkind=cat(1,newkind,sys.kind);
                    newname=cat(1,newname,sys.name);
 end

 sys.pos=newpos;
 sys.kind=newkind;
 sys.name=newname;

 %now, weed out those that aren't actually in ppiped
 coeff=(ppiped\sys.pos')';
 
 %this part creates the mask based on the vector coefficients being between
 %0 and 1 (ie, it is in the ppiped)
 a=coeff+eps<1.0;
 b=coeff+eps>=0.0;
 c=a+b;
 d=c>1;
 e=sum(d,2);
 mask=e==sys.dim;
 siz=size(sys.pos);
 masklist=[1:siz(1)];
 accept=mask.*masklist';
 accept=accept(accept>0);
 
 sys.pos=sys.pos(accept,:);
 sys.kind=sys.kind(accept);
 sys.name=sys.name(accept,:);
 numatms=size(sys.pos);
 sys.numatms=numatms(1);
 
 supercell=sys;
 supercell.latvec=vectors';