function [sys,run]=mc(system,run)
% MC runs a monte carlo routine based on the Metropolis algorithm
%   [SYS RUN]=MC(SYSTEM, RUN) are a modified system structure and modified
%   run structure.
%FIX???
%   MC is basically a loop broken into 3 parts
%   a)Sample: sample values of quantities to average (e.g., energy)
%	b)Altersystem: create new values of the relevant variables (position,
%       spin, kind, etc.) for each atom
%	c)Accept/Reject: accept or reject new values according to energy criterion
%   The run variable is a struct that contains the information for a
%   specific MC run.  It includes
%    run.N = The total number of MC steps.
%    run.equilibN = The number of equilibration steps before averages are
%    taken.
%    run.alter = The alteration that the system undergoes at each MC step.
%    values include
%      'SwapKind': swaps the kind for two atoms chosen at random
%      'ChangeKind': changes the kind for an atom at random
%
%   %Example:
%   >>run.beta=5.0;
%   >>run.equilibN=100;
%   >>run.N=1000;
%   >>sys=makesys;
%   >>[newsys newrun]=mc(sys,run)
%
%   The above example runs the monte carlo routine 1000 times after an
%   equilibration of 100 steps.  Newsys will contain the final system and
%   newrun will contain running values to be averaged (as well as run
%   parameters).  In order to keep a running average of a variable, the
%   user must calculate the variable and append it to an array at the end
%   of each step.  Make this variable a field in the run structure.
%   Averages can be found at the beginning of the main for loop.
%
% See also ACCEPTREJECT, ALTERSYS, FINDSYSENERGY

%initialize system
t0=clock;
disp(['MC: Starting run']);
sys=system;
% For quick random numers 
rndlst=randint(1,4*run.N,[1,sys.numatms]); 
rndcnt=1;
%make sure system is self consistent
check(sys);
% Initialize averages
run.nacc=0;
run.E_all=zeros(run.N,1);
run.E_u_all=zeros(run.N,1);
run.N_all=zeros(run.N,sys.nkind);

%Calculate intialized system energy
oldE=findSysEnergy(sys);
%Chemical potential contribution
oldN=NumEachKind(sys);
oldE_u=oldE-run.mu*oldN';

%Do MC steps
for i=1:run.N
    %print out step number
    if(mod(i,5000)==0)
        disp(['MC: step ' num2str(i)]);
    end

    %Collect samples
    %run=mcsample(oldE,oldE_u,oldN,i,run);
    run.E_all(i)=oldE;
    run.E_u_all(i)=oldE_u;
    run.N_all(i,:)=oldN;

    %Alter the system in some way according to altersys.m
    %chose atoms at random to change
    %nalter=1*ceil(sys.numatms/100);
    nalter=1;
    switch run.alter
        case 'ChangeKind' % This changes all distinct atoms
            if (nalter>1) %  this will be slow
                tmp=randperm(sys.numatms);
                alter=tmp(1:nalter);
            else
            alter=rndlst(rndcnt);
            rndcnt=rndcnt+1;
            %randint(1,1*nalter,[1,sys.numatms]);
            end
        case 'SwapKind' % This allows identical type atoms to swap
               tmp=randperm(sys.numatms);
               alter=tmp(1:2*nalter);
        otherwise
            error('ERROR MC: No such alteration (run.alter) found')
    end
    newsys=altersys(sys,run,alter);
    rndcnt=rndcnt+nalter;

    %Calculate new system energy
    dE=findDeltaSysEnergy(newsys,sys,alter);
    newE=oldE+dE;
%     tnewE=findSysEnergy(newsys);
%     [tnewE newE]
    %Chemical potential contribution
    newN=NumEachKind(newsys);
    newE_u=newE-run.mu*newN';

    %Accept or reject the altered system
    accrej=acceptreject(oldE_u,newE_u,run.beta);
    if(accrej=='accept')
        sys=newsys;
        oldE=newE;
        oldN=newN;
        oldE_u=newE_u;
        run.nacc=run.nacc+1;
    end

end %End MC loop

%Collect final samples
run=mcsample(oldE,oldE_u,oldN,run.N+1,run);
%Collect averages
run=mcaverage(run);
% Print out final time
dt=etime(clock,t0);
dt_step=dt/run.N;
disp(['MC: Ending run.  Total time (s): ' num2str(dt) ' Time per step: ' num2str(dt_step)]);
